==> buster-0.7.12.tgz: package/lib/buster/browser-wiring.js <==
(function (B) {
    B.env = B.env || {};

    var errorQueue = [];

    // Need to bind this immediately, so we can report errors that happen after
    // this file has loaded, but before the test runner is initialized
    window.onerror = function () {
        errorQueue.push(arguments);
    };

    // Globally uncaught errors will be emitted as messages through
    // the test runner
    function handleUncaughtError(runner, args) {
        if (args.length === 3) {
            var message = args[0];
            var url = args[1];
            var line = args[2];

            var cp = B.env.contextPath || window.location;
            var index = (url || "").indexOf(cp);
            if (index >= 0) {
                url = "." + url.slice(index + cp.length);
            }

            if (line === 1 && message === "Error loading script") {
                message = "Unable to load script " + url;
            } else if (url) {
                message = url + ":" + line + " " + message;
            } else {
                message = message.replace("uncaught exception: ", "");
            }
        }

        runner.emit("uncaughtException", {
            name: "UncaughtError",
            message: message
        });

        return true;
    };

    function uncaughtErrors(runner) {
        for (var i = 0, l = errorQueue.length; i < l; ++i) {
            handleUncaughtError(runner, errorQueue[i]);
        }

        window.onerror = function () {
            handleUncaughtError(runner, arguments);
        };
    }

    // Emit messages from the evented logger buster.console through
    // the test runner
    function logger(runner) {
        B.console.on("log", function (msg) {
            runner.emit("log", msg);
        });
    }

    // Collect test cases and specs created with buster.testCase
    // and buster.spec.describe
    function testContexts() {
        var contexts = [];
        B.addTestContext = function (context) { contexts.push(context); };
        B.testContext.on("create", B.addTestContext);
        return contexts;
    }

    // Clear scripts and use the browserEnv object from buster-test to
    // reset the document between tests runs
    function documentState(runner) {
        var scripts = document.getElementsByTagName("script"), script;
        while ((script = scripts[0])) {
            script.parentNode.removeChild(script);
        }
        var env = B.browserEnv.create(document.body);
        env.listen(runner);
    }

    function shouldAutoRun(config) {
        var autoRunPropertyIsSet = config.hasOwnProperty("autoRun");
        return config.autoRun || !autoRunPropertyIsSet;
    }

    function shouldResetDoc(config) {
        var resetDocumentPropertyIsSet = config.hasOwnProperty("resetDocument");
        return config.resetDocument || !resetDocumentPropertyIsSet;
    }

    // Wire up the test runner. It will start running tests when
    // the environment is ready and when we've been told to run.
    // Note that run() and ready() may occur in any order, and
    // we cannot do anything until both have happened.
    //
    // When running tests with buster-server, we'll be ready() when
    // the server sends the "tests:run" message. This message is sent
    // by the server when it receives the "loaded all scripts" message
    // from the browser. We'll usually run as soon as we're ready.
    // However, if the autoRun option is false, we will not run
    // until buster.run() is explicitly called.
    //
    // For static browser runs, the environment is ready() when
    // ready() is called, which happens after all files have been
    // loaded in the browser. Tests will run immediately for autoRun:
    // true, and on run() otherwise.
    //
    function testRunner(runner) {
        var ctxts = B.wire.testContexts();
        var ready, started, alreadyRunning, config;

        function attemptRun() {
            if (!ready || !started || alreadyRunning) { return; }
            alreadyRunning = true;
            if (typeof runner === "function") { runner = runner(); }
            if (shouldResetDoc(config)) { B.wire.documentState(runner); }
            if (config.captureConsole) { B.captureConsole(); }

            for (var prop in config) {
                runner[prop] = config[prop];
            }

            runner.runSuite(B.testContext.compile(ctxts, config.filters));
        }

        return {
            ready: function (options) {
                config = options || {};
                ready = true;
                started = started || shouldAutoRun(config);
                attemptRun();
            },

            run: function () {
                started = true;
                attemptRun();
            }
        };
    }

    B.wire = function (testRunner) {
        var wiring = B.wire.testRunner(testRunner);
        B.ready = wiring.ready;
        B.run = wiring.run;
        return wiring;
    };

    B.wire.uncaughtErrors = uncaughtErrors;
    B.wire.logger = logger;
    B.wire.testContexts = testContexts;
    B.wire.documentState = documentState;
    B.wire.testRunner = testRunner;
}(buster));

// TMP Performance fix
(function () {
    var i = 0;

    buster.nextTick = function (cb) {
        i += 1;

        if (i === 10) {
            setTimeout(function () {
                cb();
            }, 0);

            i = 0;
        } else {
            cb();
        }
    };
}());

buster.sinon = sinon;
try {
    delete this.define;
    delete this.when;
    delete this.async;
    delete this.platform;
    delete this._;
} catch (e) {
    this['define'] = undefined;
    this['when'] = undefined;
    this['async'] = undefined;
    this['platform'] = undefined;
    this['_'] = undefined;
}

==> buster-0.7.15.tgz: package/lib/buster/browser-wiring.js <==
(function (B) {
    B.env = B.env || {};

    var errorQueue = [];

    // Need to bind this immediately, so we can report errors that happen after
    // this file has loaded, but before the test runner is initialized
    window.onerror = function () {
        errorQueue.push(arguments);
    };

    // Globally uncaught errors will be emitted as messages through
    // the test runner
    function handleUncaughtError(runner, args) {
        if (args.length >= 3) {
            var message = args[0];
            var url = args[1];
            var line = args[2];

            var cp = B.env.contextPath || window.location;
            var index = (url || "").indexOf(cp);
            if (index >= 0) {
                url = "." + url.slice(index + cp.length);
            }

            if (line === 1 && message === "Error loading script") {
                message = "Unable to load script " + url;
            } else if (url) {
                message = url + ":" + line + " " + message;
            } else {
                message = message.replace("uncaught exception: ", "");
            }
        }

        runner.emit("uncaughtException", {
            name: "UncaughtError",
            message: message
        });

        return true;
    };

    function uncaughtErrors(runner) {
        for (var i = 0, l = errorQueue.length; i < l; ++i) {
            handleUncaughtError(runner, errorQueue[i]);
        }

        window.onerror = function () {
            handleUncaughtError(runner, arguments);
        };
    }

    // Emit messages from the evented logger buster.console through
    // the test runner
    function logger(runner) {
        B.console.on("log", function (msg) {
            runner.emit("log", msg);
        });
    }

    // Collect test cases and specs created with buster.testCase
    // and buster.spec.describe
    function testContexts() {
        var contexts = [];
        B.addTestContext = function (context) { contexts.push(context); };
        B.testContext.on("create", B.addTestContext);
        return contexts;
    }

    // Clear scripts and use the browserEnv object from buster-test to
    // reset the document between tests runs
    function documentState(runner) {
        var scripts = document.getElementsByTagName("script"), script;
        while ((script = scripts[0])) {
            script.parentNode.removeChild(script);
        }
        var env = B.browserEnv.create(document.body);
        env.listen(runner);
    }

    function shouldAutoRun(config) {
        var autoRunPropertyIsSet = config.hasOwnProperty("autoRun");
        return config.autoRun || !autoRunPropertyIsSet;
    }

    function shouldResetDoc(config) {
        var resetDocumentPropertyIsSet = config.hasOwnProperty("resetDocument");
        return config.resetDocument || !resetDocumentPropertyIsSet;
    }

    // Wire up the test runner. It will start running tests when
    // the environment is ready and when we've been told to run.
    // Note that run() and ready() may occur in any order, and
    // we cannot do anything until both have happened.
    //
    // When running tests with buster-server, we'll be ready() when
    // the server sends the "tests:run" message. This message is sent
    // by the server when it receives the "loaded all scripts" message
    // from the browser. We'll usually run as soon as we're ready.
    // However, if the autoRun option is false, we will not run
    // until buster.run() is explicitly called.
    //
    // For static browser runs, the environment is ready() when
    // ready() is called, which happens after all files have been
    // loaded in the browser. Tests will run immediately for autoRun:
    // true, and on run() otherwise.
    //
    function testRunner(runner) {
        var ctxts = B.wire.testContexts();
        var ready, started, alreadyRunning, config;

        function attemptRun() {
            if (!ready || !started || alreadyRunning) { return; }
            alreadyRunning = true;
            if (typeof runner === "function") { runner = runner(); }
            if (shouldResetDoc(config)) { B.wire.documentState(runner); }
            if (config.captureConsole) { B.captureConsole(); }

            for (var prop in config) {
                runner[prop] = config[prop];
            }

            runner.runSuite(B.testContext.compile(ctxts, config.filters));
        }

        return {
            ready: function (options) {
                config = options || {};
                ready = true;
                started = started || shouldAutoRun(config);
                attemptRun();
            },

            run: function () {
                started = true;
                attemptRun();
            }
        };
    }

    B.wire = function (testRunner) {
        var wiring = B.wire.testRunner(testRunner);
        B.ready = wiring.ready;
        B.run = wiring.run;
        return wiring;
    };

    B.wire.uncaughtErrors = uncaughtErrors;
    B.wire.logger = logger;
    B.wire.testContexts = testContexts;
    B.wire.documentState = documentState;
    B.wire.testRunner = testRunner;
}(buster));

// TMP Performance fix
(function () {
    var i = 0;

    buster.nextTick = function (cb) {
        i += 1;

        if (i === 10) {
            setTimeout(function () {
                cb();
            }, 0);

            i = 0;
        } else {
            cb();
        }
    };
}());

buster.sinon = sinon;
try {
    delete this.define;
    delete this.when;
    delete this.async;
    delete this.platform;
    delete this._;
} catch (e) {
    this['define'] = undefined;
    this['when'] = undefined;
    this['async'] = undefined;
    this['platform'] = undefined;
    this['_'] = undefined;
}
